# mgpustat

A GPU statistics utility for Apple Silicon Macs, inspired by gpustat.

## Installation

```bash
$ pip install mgpustat
```

## Usage

Run the utility with:

```bash
$ sudo mgpustat
```

You may need to grant terminal access to your IDE or terminal emulator in System Preferences > Security & Privacy > Privacy > Full Disk Access.

## Features

- Displays overall GPU usage
- Shows individual GPU engine usage (i.e. cores)
- Lists top GPU-using processes

## Requirements

- macOS with Apple Silicon (M1 or newer)
- Python 3.7 or newer

## Contributing

Please feel free to submit a Pull Request.

## License

This project is licensed under the MIT License - see the LICENSE file for details.